@@ -2,13 +2,14 @@ from dataclasses import dataclass
 from enum import Enum
 from typing import Any, Callable, Optional, Union
 
-from sqlalchemy import Column, Table, and_, false, func, or_, true, extract
+from sqlalchemy import Column, Table, and_, extract, false, func, or_, true
 from sqlalchemy.orm.relationships import RelationshipProperty
 from sqlalchemy.sql.elements import BooleanClauseList
 from typing_extensions import TypeGuard
 
 from souswift_core.filters import _comparison as cp
 from souswift_core.filters.base import Filter
+from souswift_core.providers import Driver
 
 
 def _attr(
@@ -137,9 +138,20 @@ class FilterIterator(Filter):
                 yield item.field
 
 
-def day(column: Column):
-    return extract('DAY', column)
+class DateFilter:
+    def __init__(self, driver: Driver):
+        self.driver = driver
 
+    @staticmethod
+    def format(self, date_part: int):
+        return str(date_part).zfill(2)
 
-def month(column: Column):
-    return extract('MONTH', column)
+    def day(self, column: Column):
+        if self.driver is Driver.SQLITE:
+            return func.strftime('%d', column)
+        return extract('DAY', column)
+
+    def month(self, column: Column):
+        if self.driver is Driver.SQLITE:
+            return func.strftime('%m', column)
+        return extract('MONTH', column)
