@@ -1,6 +1,7 @@
 from contextlib import asynccontextmanager
 from typing import AsyncGenerator
 
+from context_handler import AsyncContext
 from sqlalchemy import text
 from sqlalchemy.ext.asyncio import AsyncConnection
 
@@ -25,3 +26,5 @@ class ConnectionProvider(DatabaseProvider):
         async with self.acquire() as connection:
             await connection.execute(text('SELECT 1'))
         self.logger.info('Database Connection succeeded')
+
+    Context = AsyncContext[AsyncConnection]
