@@ -1,6 +1,7 @@
 from contextlib import asynccontextmanager
 from typing import AsyncGenerator
 
+from context_handler import AsyncContext
 from sqlalchemy import text
 from sqlalchemy.ext.asyncio import AsyncSession
 from sqlalchemy.orm import sessionmaker
@@ -32,3 +33,5 @@ class SessionProvider(DatabaseProvider):
         async with self.acquire() as session:
             await session.execute(text('SELECT 1'))
         self.logger.info('Database Connection succeeded')
+
+    Context = AsyncContext[AsyncSession]
